# MQTT to SQLite Logger

## Installation

```bash
pip install mqtt-logger
```

## Examples

```python
hello = 3

```

## Unit Tests

```bash
# Run tests in poetry virtual environment
poetry run pytest
```